==> underscore-1.0.0.tgz: package/karma.conf.js <==
/**
 * @author harttle<yangjvn@126.com>
 * @file Karma 配置文件
 */

var paths = {};

module.exports = function (config) {
    config.set({
        // Set globally available variables
        globals: {
            paths: JSON.stringify(paths)
        },

        // base path that will be used to resolve all patterns (eg. files, exclude)
        basePath: '',

        // frameworks to use
        // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
        // Important: 下列数组中文件将『逆序载入』
        frameworks: ['mocha', 'requirejs', 'chai-sinon'],

        // list of files / patterns to load in the browser
        files: [
            'test-main.js', {
                pattern: 'src/*.js',
                included: false
            }, {
                pattern: 'test/*.js',
                included: false
            }, {
                pattern: 'amd_modules/**/*.js',
                included: false
            }
        ],

        // list of files to exclude
        exclude: [],

        // preprocess matching files before serving them to the browser
        // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
        preprocessors: {
            'test-main.js': ['global'],
            // source files, that you wanna generate coverage for
            // do not include tests or libraries
            // (these files will be instrumented by Istanbul)
            'index.js': ['coverage']
        },

        // test results reporter to use
        // possible values: 'dots', 'progress'
        // available reporters: https://npmjs.org/browse/keyword/karma-reporter
        reporters: ['mocha'],
        htmlReporter: {
            outputDir: 'test-reports/result'
        },
        coverageReporter: {
            reporters: [
                {
                    type: 'html',
                    dir: 'test-reports/coverage' // relative to basePath
                }, {
                    type: 'text-summary'
                }, {
                    type: 'lcov',
                    dir: 'test-reports/coverage'
                }
            ]
        },

        // web server port
        port: 9876,

        // enable / disable colors in the output (reporters and logs)
        colors: true,

        // level of logging
        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
        // Note: 如果要调试Karma，请设置为DEBUG
        logLevel: config.LOG_INFO,

        // enable / disable watching file and executing tests whenever any file changes
        // Note: 代码改动自动运行测试，需要singleRun为false
        autoWatch: false,

        // start these browsers
        // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
        browsers: [process.env.BROWSER || 'ChromeHeadless'],

        // Continuous Integration mode
        // if true, Karma captures browsers, runs the tests and exits
        // 脚本调用请设为 true
        singleRun: true
    });
};

==> underscore-1.0.1.tgz: package/karma.conf.js <==
/**
 * @author harttle<yangjvn@126.com>
 * @file Karma 配置文件
 */

var paths = {};

module.exports = function (config) {
    config.set({
        // Set globally available variables
        globals: {
            paths: JSON.stringify(paths)
        },

        // base path that will be used to resolve all patterns (eg. files, exclude)
        basePath: '',

        // frameworks to use
        // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
        // Important: 下列数组中文件将『逆序载入』
        frameworks: ['mocha', 'requirejs', 'chai-sinon'],

        // list of files / patterns to load in the browser
        files: [
            'test-main.js', {
                pattern: 'src/*.js',
                included: false
            }, {
                pattern: 'test/*.js',
                included: false
            }, {
                pattern: 'amd_modules/**/*.js',
                included: false
            }
        ],

        // list of files to exclude
        exclude: [],

        // preprocess matching files before serving them to the browser
        // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
        preprocessors: {
            'test-main.js': ['global'],
            // source files, that you wanna generate coverage for
            // do not include tests or libraries
            // (these files will be instrumented by Istanbul)
            'src/**/*.js': ['coverage']
        },

        // test results reporter to use
        // possible values: 'dots', 'progress'
        // available reporters: https://npmjs.org/browse/keyword/karma-reporter
        reporters: ['mocha'],
        coverageReporter: {
            reporters: [
                {
                    type: 'html',
                    dir: 'coverage' // relative to basePath
                }, {
                    type: 'text-summary'
                }, {
                    type: 'lcov',
                    dir: 'coverage/'
                }
            ]
        },

        // web server port
        port: 9876,

        // enable / disable colors in the output (reporters and logs)
        colors: true,

        // level of logging
        // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
        // Note: 如果要调试Karma，请设置为DEBUG
        logLevel: config.LOG_INFO,

        // enable / disable watching file and executing tests whenever any file changes
        // Note: 代码改动自动运行测试，需要singleRun为false
        autoWatch: false,

        // start these browsers
        // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
        browsers: [process.env.BROWSER || 'ChromeHeadless'],

        // Continuous Integration mode
        // if true, Karma captures browsers, runs the tests and exits
        // 脚本调用请设为 true
        singleRun: true
    });
};
